<?php

namespace IDT\Core\Api\User;

if ( ! defined( "ABSPATH" ) ) {
  exit;
}

use WP_REST_Request;

class IDT_UserEndpoint_Identify {

  /**
   * IDT_UserEndpoint_Identify constructor.
   */
  public function __construct() {
	add_action( 'rest_api_init', array( $this, 'create_user_info_endpoint' ) );
  }

  /*
   * This function will register the endpoint to receive traffic on
   *
   */
  public function create_user_info_endpoint() {
	register_rest_route( 'idt/v1', '/getcustomer/', array(
		'methods'  => 'POST',
		'callback' => array( $this, 'get_user_id_from_cookie' ),
		'permission_callback' => '__return_true'

	) );
  }

  /**
   * This function will retrieve a cookie from a third party application.
   * The cookie will be sent as a header field cookie:12345678
   * It will then check if the same cookie was found in the browser storage, which would imply the user is logged in.
   * After that it will verify the cookie with the server, which makes sure all cookie details are valid.
   * Finally it will return a response to the sender of the request, containing the user ID, or an empty value.
   *
   * @param WP_REST_Request $request
   *
   * @return false|mixed|string|void
   * @throws \Exception
   */
  public function get_user_id_from_cookie( WP_REST_Request $request ) {

	$api_key = get_option( 'wc_settings_idt_api_key' );
	if ( $request->get_param( 'apiKey' ) == $api_key ) {

	  if ( isset( $_COOKIE['IDT_USER'] ) ) {
		$user_id = wp_validate_auth_cookie( $_COOKIE['IDT_USER'], 'logged_in' );
		if ( is_numeric( $user_id ) ) {
		  return [ 'userID' => $user_id ];
		}
	  }

	  if ( isset( $_COOKIE[ LOGGED_IN_COOKIE ] ) ) {
		$user_id = wp_validate_auth_cookie( $_COOKIE[ LOGGED_IN_COOKIE ], 'logged_in' );
		if ( is_numeric( $user_id ) ) {
		  return [ 'userID' => $user_id ];
		}
	  }

	  return;
	} else {
	  throw new \Exception( 'ApiKey Mismatch' );
	}
  }
}