<?php

namespace IDT\Core\LoginCookie;

use IDT\Core\Helpers\Helper;

if (!defined("ABSPATH")) {
    exit;
}

class IDT_UserCookie
{
    private $cookie_domain;
    
    public function __construct()
    {
        if (Helper::settings_synced_already()) {
            add_action('init', array($this, 'create_the_custom_cookie'));
            add_action('wp_logout', array($this, 'destroy_the_custom_cookie'));
            add_action('init', array($this, 'create_the_custom_wordpress_cookie'));

            add_filter('woocommerce_cookie', array($this, 'clone_the_woocommerce_cart_cookie'), 50);

            $this->cookie_domain = Helper::determine_cookie_domain();
        }
    }

    /**
     * Creates a custom cookie if the wordpress login cookie is set
     */
    public function create_the_custom_cookie()
    {
        if (isset($_COOKIE['wordpress_logged_in_' . COOKIEHASH]) && !headers_sent()) {
            setcookie('IDT_USER', $_COOKIE['wordpress_logged_in_' . COOKIEHASH], 0, '/', $this->cookie_domain);
        }
    }

    /**
     * Creates a wordpress cookie if the custom cookie is set
     */
    public function create_the_custom_wordpress_cookie()
    {
        if (isset($_COOKIE['IDT_USER']) && !headers_sent()) {
            setcookie('wordpress_logged_in_' . COOKIEHASH, $_COOKIE['IDT_USER'], 0, '/', $this->cookie_domain);
        }
    }

    /**
     * This will destroy the custom cookies contents, and set its expire date to the past, so it will vanish on the next request
     */
    public function destroy_the_custom_cookie()
    {
        if (isset($_COOKIE['IDT_USER']) && !headers_sent()) {
            unset($_COOKIE['IDT_USER']);
            unset($_COOKIE['wordpress_logged_in_' . COOKIEHASH]);
            setcookie('IDT_USER', '', 1, '/', $this->cookie_domain);
            setcookie('wordpress_logged_in_' . COOKIEHASH, '', 1, '/', $this->cookie_domain);
            setcookie('wordpress_logged_in_' . COOKIEHASH, '', 1, '/', '.' . $this->cookie_domain);
        }
    }

    /**
     * Hooks into the 'woocommerce_cookie' filter. Takes the key of the woocommerce cart session cookie,
     * and duplicates that cookie so it is available to the editor. Which will send it back when adding
     * a product to cart
     *
     * @param $woocommerce_cookie_name
     */
    public function clone_the_woocommerce_cart_cookie($woocommerce_cookie_name)
    {
        if (get_option('wc_settings_idt_guest_mode') != 1 || headers_sent()) {
            return $woocommerce_cookie_name;
        }
        
        if (isset($_COOKIE[$woocommerce_cookie_name])) {
            setcookie($woocommerce_cookie_name, $_COOKIE[$woocommerce_cookie_name], 0, '/', $this->cookie_domain);
        }

        return $woocommerce_cookie_name;
    }
}