<?php

namespace IDT\Core\WooCommerce;

use IDT\Core\Helpers\Helper;

if ( ! defined( 'ABSPATH' ) ) {
  exit;
}

class IDT_Cart_Session {
  /**
   * IDT_Cart_Session constructor.
   */
  public function __construct() {
	$this->cookie_domain = Helper::determine_cookie_domain();

	add_action( 'woocommerce_thankyou', array( $this, 'empty_the_cart' ) );

	if ( get_option( 'wc_settings_idt_guest_mode' ) == 1 ) {
	  add_action( 'woocommerce_loaded', array( $this, 'clone_cart_cookies' ) );
	}
  }

  /**
   * Empty The cart session cookie
   */
  public function empty_the_cart() {
	setcookie( 'woocommerce_cart_hash', 0, time() - 901, '/', $this->cookie_domain );
	setcookie( 'woocommerce_items_in_cart', 0, time() - 901, '/', $this->cookie_domain );
  }

  /**
   * Clone the cookies set by woocommerce, so they are available to the Instant Design Tool.
   */
  public function clone_cart_cookies() {
	if ( ! is_user_logged_in() ) {
	  WC()->initialize_session();
	  WC()->session->set_customer_session_cookie( true );
	  foreach ( $_COOKIE as $cookieName => $cookie ) {
		if ( ! $cookie == 0 ) {
		  if ( strstr( $cookieName, 'woocommerce_session' ) ) {
			setcookie( $cookieName, $cookie, 0, '/', $this->cookie_domain );
		  }
		}
	  }
	} else {
	  //User is logged in so we need to use the logged in mode.
	  foreach ( $_COOKIE as $cookieName => $cookie ) {
		if ( ! $cookie == 0 ) {
		  if ( strstr( $cookieName, 'woocommerce_session' ) ) {
			setcookie( $cookieName, 'this value has been removed to prevent errors', time() - 20, '/', Helper::determine_cookie_domain() );
		  }
		}
	  }
	}
  }
}